=========
Changelog
=========

Version 0.9.0
===========

- Finished core features:
	- Attention Mechanism
	- Diffusion Graph Convolution
	- GRU based on the above
	- reimplementation of the model used in https://milets19.github.io/papers/milets19_paper_8.pdf

Version 0.9.1
===========

- Wrote README.md
- Added requirements
- uploading to TestPyPi

Version 0.9.2
===========

- fixing README.md
- removed pyscaffold spam from setup.cfg
- uploading to TestPyPi and testing if it installs correctly
